pyjabber.db package
===================

Submodules
----------

pyjabber.db.database module
---------------------------

.. automodule:: pyjabber.db.database
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pyjabber.db
   :members:
   :undoc-members:
   :show-inheritance:
